*This program takes the csv files exported by BorderIntersect / make_intersect_csv.py and uses them to harmonize Haines' census data (ICPSR 02896) to a base year using the Hornbeck (2010) method. This program is written for me to harmonize the years 1790-1900, every five years, to 1840. Change it as you will.  Rewritten from Hornnbeck's code found at https://www.dropbox.com/s/1cygkeoo4p89vrw/BWreplication_BorderFixes.rar .



clear all
*Change the directory to the one you want to be using
*cd ""

*The data for non-census years assumes exponential growth. 
*Everything is using 1840 boarders.

*This takes files made by make_intersect_csv.py and uses them to create county data that is harmonized to the base year specified.

foreach year of numlist 1790(10)1900 {

*Just set 1840 here
local base_year = 1840


insheet using Export_US_county_`year'_conflated_b`base_year'_Int.csv, comma

rename icpsrfip fips`year'
*One doesn't need to move 1840 values to 1840 values.
if `year' != `base_year'{
rename icpsrfip_1 fips`base_year'
}
* area_sqmii is the intersect,  area_sqmi is the `year' area
rename area_sqmi  area_sqmi`year'


collapse (sum) area_sqmii, by(fips`year'  area_sqmi`year' fips`base_year')
gen percent =  area_sqmii/area_sqmi`year'


drop if fips`base_year' == 0 | fips`year' == 0 | fips`base_year' == . | fips`year' == .
*drop if percent < 0.01 \\\ Don't bother to do this because if it is small anyway who cares

gen fips = fips`year'
sort fips

merge m:m fips using pop`year'.dta
keep if _merge == 3 | floor(fips) == 11001
drop _merge

*If there is missing data this lets on preform the sum anyway and then change back to missing.
*I am using the varlist county - end, end being a variable I created to signify the end of my data.
*This will of course need to be changed for your situation.
foreach var of varlist state county-end {
	*I am not replacing the ID variables if they are missing.
	if !inlist("`var'", "state", "county", "name", "fips", "statefip", "year") {
		replace `var' = -100000000000000000000000 if `var'==. & percent>=0.01
		replace `var' = 0 if `var'==. & percent<0.01
}
}


*If I trust those areas they can be used to weight the data
*I am using the varlist county - end, end being a variable I created to signify the end of my data.
*This will of course need to be changed for your situation.
foreach var of varlist state county-end {
	if !inlist("`var'", "state", "county", "name", "fips", "statefip", "year") {
		replace `var' = `var'*percent
}
}

replace fips`base_year' = round(fips`base_year', 0.1)
*Assume all of DC is one place
replace fips`year' = 11001 if floor(fips`year')==11001
replace fips`base_year' = 11001 if floor(fips`base_year')==11001
*Assume all of Alexandria, VA is one place.
replace fips`base_year' = 51013 if fips`base_year' == 51510

*I am using the varlist that makes sense for my data. Change for yours.
collapse (sum) area_sqmii totpop-placeholder free_adult-end ///
	, by(fips`base_year' year)

*Change back to missing if it use to be missing.	
foreach var of varlist area_sqmii totpop-placeholder free_adult-end {
replace `var' = . if `var' < 0
}

compress

save Pop_Data_`year'_`base_year'counties.dta, replace

clear all
}




*Make the interpolated five year data.
*This can be changed for any intermediate year.
foreach year of numlist 1790(10)1890 {

local base_year = 1840
local year_plus_five = `year' + 5
local year_plus_ten = `year' + 10

*I commented out those parts because I decided to have base year to base year file.
*if `year' != `base_year'{
use Pop_Data_`year'_`base_year'counties.dta, clear
*}
*else{
*use pop`base_year'.dta, clear
*drop state name county statefip
*rename fips fips`base_year'
*}

*if `year_plus_ten' != `base_year'{
append using Pop_Data_`year_plus_ten'_`base_year'counties.dta
*}
*else{
*append using pop`base_year'.dta
*drop state name county statefip
*replace fips`base_year' = fips if fips`base_year' == .
*}

replace fips = fips`base_year' if fips == .
drop if fips == .

drop end
gen end = .

sort fips year

*I keep small list of variables I want to harmonize.
keep totpop urb_2500 urb25 free_adult fips`base_year' year
reshape wide totpop urb_2500 urb25 free_adult, i(fips`base_year') j(year)

*Just change these variables.
local prefix totpop urb_2500 urb25 free_adult
foreach p of local prefix  {
gen `p'`year_plus_five' = `p'`year'*(exp(((ln(`p'`year_plus_ten') - ln(`p'`year'))/10)*5)) ///
	if `p'`year' != 0 & `p'`year_plus_ten' != 0
replace `p'`year_plus_five' = (exp((ln(`p'`year_plus_ten')/10)*5)) ///
	if `p'`year'== 0 & `p'`year_plus_ten' != 0
replace `p'`year_plus_five' = `p'`year'*(exp(((-ln(`p'`year'))/10)*5)) ///
	if `p'`year' != 0 & `p'`year_plus_ten' == 0
replace `p'`year_plus_five' = 0	if `p'`year' == 0 & `p'`year_plus_ten' == 0
}

foreach p of local prefix  {
drop `p'`year' `p'`year_plus_ten'
rename `p'`year_plus_five' `p'
}

gen year = `year_plus_five'

compress

save Pop_Data_`year_plus_five'_`base_year'counties.dta, replace
}
